@@ -1,12 +1,12 @@
 package WordList::Test::OneTwo;
 
-our $DATE = '2020-08-23'; # DATE
-our $VERSION = '0.7.6'; # VERSION
+our $DATE = '2021-01-28'; # DATE
+our $VERSION = '0.7.7'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("num_words_contains_nonword_chars",0,"longest_word_len",3,"num_words_contains_whitespace",0,"num_words_contain_unicode",0,"num_words_contain_nonword_chars",0,"shortest_word_len",3,"num_words",2,"avg_word_len",3,"num_words_contains_unicode",0,"num_words_contain_whitespace",0); # STATS
+our %STATS = ("num_words",2,"shortest_word_len",3,"num_words_contains_nonword_chars",0,"num_words_contain_nonword_chars",0,"num_words_contains_unicode",0,"num_words_contain_whitespace",0,"num_words_contain_unicode",0,"num_words_contains_whitespace",0,"longest_word_len",3,"avg_word_len",3); # STATS
 
 1;
 # ABSTRACT: Wordlist that contains "one" and "two"
@@ -21,7 +21,7 @@ WordList::Test::OneTwo - Wordlist that contains "one" and "two"
 
 =head1 VERSION
 
-This document describes version 0.7.6 of WordList::Test::OneTwo (from Perl distribution WordList), released on 2020-08-23.
+This document describes version 0.7.7 of WordList::Test::OneTwo (from Perl distribution WordList), released on 2021-01-28.
 
 =head1 SYNOPSIS
 
@@ -56,7 +56,7 @@ Source repository is at L<https://github.com/perlancar/perl-WordList>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordList>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-WordList/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -68,7 +68,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
