@@ -1,9 +1,9 @@
 package WordListBase;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-08-23'; # DATE
+our $DATE = '2021-01-28'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.7.6'; # VERSION
+our $VERSION = '0.7.7'; # VERSION
 
 use strict 'subs', 'vars';
 
@@ -49,7 +49,7 @@ WordListBase - WordList base class
 
 =head1 VERSION
 
-This document describes version 0.7.6 of WordListBase (from Perl distribution WordList), released on 2020-08-23.
+This document describes version 0.7.7 of WordListBase (from Perl distribution WordList), released on 2021-01-28.
 
 =head1 DESCRIPTION
 
@@ -69,7 +69,7 @@ Source repository is at L<https://github.com/perlancar/perl-WordList>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordList>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-WordList/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -85,7 +85,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
